-- ==============================================================================================
-- FINAL FANTASY VI T-EDITION TRANSLATION VIEWER LOGIC
-- by Clyde "Tomato" Mandelin
-- ==============================================================================================

-- TODO
-- items in script dialogue
-- skills in script dialogue?
-- make all names appear in char spans?
-- a/an/the/some for items


-- ==============================================================================================
-- BASIC GAME MODES
-- It's a bit difficult to tell when a certain part of the game is running, but
-- here is some basic info that helps. The address the SNES' NMI jumps to is
-- usually found at RAM address 0x0008 and is 2 bytes long. Different modes
-- in the game have different addresses here, so the following is somewhat
-- helpful to know. Because they all have 5C in then, it's easiest to simply
-- check byte 0x0009 in RAM.
--
-- When RAM address 0x0008 contains 0x565C (little endian): BATTLE MODE
-- When RAM address 0x0008 contains 0x835C (little endian): MAIN GAME
-- When RAM address 0x0008 contains 0xDF5C (little endian): MENUS AND SUCH
-- ==============================================================================================
MAIN_PAGE_NAME   = "Final Fantasy VI T-Edition/main.html"
TITLE_PAGE_NAME  = "Final Fantasy VI T-Edition/title.html"


-- ==============================================================================================
-- INTERNAL VARIABLES FOR MISC USE
-- ==============================================================================================
gameMode = 0
lastGameMode = 0



-- ==============================================================================================
-- ==============================================================================================
-- This runs once before doLogic ever runs
function init()
	--loadHTML(TITLE_PAGE_NAME)
	loadHTML(MAIN_PAGE_NAME)
	callJSFunction("clearAllData")
end


-- ==============================================================================================
-- ==============================================================================================
-- This handles messages sent by the emulator, like if the player presses certain buttons or
-- other events happen within the emulator itself
function getMessage(str)
	if str == "resetgame" then
		init()
	elseif str == "loadstate" then
		loadHTML(MAIN_PAGE_NAME)
		callJSFunction("clearAllData")
	end
end


-- ==============================================================================================
-- ==============================================================================================
-- All main logic goes in here & gets called once per CPU cycle
function doLogic()
	--[[gameMode = getMemory(0x9, 1)
	if gameMode ~= lastGameMode then
		callJSFunction("clearAllData")
	end
	lastGameMode = gameMode]]--
end


-- ==================================================================================================
-- MAIN LOGIC (SCRIPT DISPLAYING, ETC.)
-- ==================================================================================================

-- Standard Bank 1 script text about to be displayed
function PC_C07FC7()
	
	-- Make Terra's name appear as "?????" if she hasn't been named yet
	if getMemory(0x7E1602, 2) == 0xCBCB then
		callJSFunction_Str2("copyHTMLElement", "#char-2a", "#char-2");
	else
		callJSFunction_Str2("copyHTMLElement", "#char-2b", "#char-2");
	end
	
	local itemID = getMemory(0x7E0583, 1)
	writeHTML("script-item-param", itemID)
	
	local textID = getA()
	callJSFunction_Str("displayScriptDiv", "#script-bank1-" .. textID)
end

-- Custom Bank 2 script text about to be displayed
function PC_C0EE3B()
	
	-- Make Terra's name appear as "?????" if she hasn't been named yet
	if getMemory(0x7E1602, 2) == 0xCBCB then
		callJSFunction_Str2("copyHTMLElement", "#char-2a", "#char-2");
	else
		callJSFunction_Str2("copyHTMLElement", "#char-2b", "#char-2");
	end

	local itemID = getMemory(0x7E0583, 1)
	writeHTML("script-item-param", itemID)
	
	local textID = getA()
	callJSFunction_Str("displayScriptDiv", "#script-bank2-" .. textID)
end

-- Script window is closing
function PC_C031BE()
	callJSFunction("closeScriptDiv")
	--callJSFunction("clearAllData")
end



-- Display various battle actions
function PC_C219BF()
	local command = getA() & 0xFF
	local argument = (getA() >> 8) & 0xFF
	
	-- Item
	if command == 0x01 then
		callJSFunction_Str("displayScriptDiv", "#item-" .. argument)
	
	-- Magic (& other similar techniques)
	elseif command == 0x02 then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
	
	-- Sword Tech
	elseif command == 0x07 then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
	
	-- Throw
	elseif command == 0x08 then
		callJSFunction_Str("displayScriptDiv", "#item-" .. argument)
	
	-- Tools
	elseif command == 0x09 then
		callJSFunction_Str("displayScriptDiv", "#item-" .. argument)

	-- Blitz
	-- NOTE: NEED TO REVISE THIS - IF A MOVE FAILS IT NEEDS TO DISPLAY THE FAILURE NOTICE INSTEAD
	elseif command == 0x0A then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)

	-- Lore/Blue Magic
	elseif command == 0x0C then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
		
	-- Slots
	elseif command == 0x0F then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
		
	-- Dance
	elseif command == 0x13 then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
		
	-- X-Magic
	elseif command == 0x17 then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
		
	-- Esper summon
	elseif command == 0x19 then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
		
	-- Pray
	elseif command == 0x1A then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
		
	-- Shock
	elseif command == 0x1B then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
		
	-- Magitek
	elseif command == 0x1D then
		callJSFunction_Str("displayScriptDiv", "#move-" .. argument)
		
	end
	
	
end



-- main script boxes created at around c084aa
-- main script hits end of line/new page at around c084a7